@@ -2,7 +2,7 @@ import os
 
 kafka_bootstrap_server_host = os.environ.get('KAFKA_BOOTSTRAP_SERVER_HOST', 'localhost:9092')
 
-anu_etl_wf_error_topic = os.environ.get('ANUVAAD_ETL_WF_ERROR_TOPIC', 'anuvaad-etl-wf-errors')
+anu_etl_wf_error_topic = os.environ.get('KAFKA_ANUVAAD_ETL_WF_ERROR_TOPIC', 'anuvaad-etl-wf-errors-v1')
 es_url = os.environ.get('ANUVAAD_DP_ES_URL', 'localhost')
 
 es_core_error_index = os.environ.get('ANUVAAD_DP_ES_CORE_ERROR_INDEX', 'anuvaad-dp-errors-core-v1')
