@@ -30,7 +30,7 @@ def log_info(message, entity):
                 "fileName": filename,
                 "lineNo": line_number,
                 "message": str(message),
-                "timeStamp": eval(str(time.time()).replace('.', '')),
+                "timeStamp": eval(str(time.time()).replace('.', '')[0:13]),
                 "auditType": "INFO"
             }
             audit_enriched = enrich_entity_details(audit, entity)
@@ -58,7 +58,7 @@ def log_debug(message, entity):
                 "fileName": filename,
                 "lineNo": line_number,
                 "message": str(message),
-                "timeStamp": eval(str(time.time()).replace('.', '')),
+                "timeStamp": eval(str(time.time()).replace('.', '')[0:13]),
                 "auditType": "DEBUG"
             }
             audit_enriched = enrich_entity_details(audit, entity)
@@ -87,7 +87,7 @@ def log_exception(message, entity, exc):
                 "fileName": filename,
                 "lineNo": line_number,
                 "message": str(message),
-                "timeStamp": eval(str(time.time()).replace('.', '')),
+                "timeStamp": eval(str(time.time()).replace('.', '')[0:13]),
                 "auditType": "EXCEPTION"
             }
             audit_enriched = enrich_entity_details(audit, entity)
@@ -118,7 +118,7 @@ def log_error(message, entity, exc):
                 "fileName": filename,
                 "lineNo": line_number,
                 "message": str(message),
-                "timeStamp": eval(str(time.time()).replace('.', '')),
+                "timeStamp": eval(str(time.time()).replace('.', '')[0:13]),
                 "auditType": "ERROR"
             }
             audit_enriched = enrich_entity_details(audit, entity)
@@ -158,10 +158,15 @@ def enrich_entity_details(audit, entity):
                     audit["module"] = metadata["module"]
                 else:
                     audit["module"] = "MOD-NA"
+                if 'requestID' in metadata.keys():
+                    audit["requestID"] = metadata["requestID"]
+                else:
+                    audit["requestID"] = "REQ-ID-NA"
             else:
                 audit["sessionID"] = "SE-ID-NA"
                 audit["userID"] = "USR-ID-NA"
                 audit["module"] = "MOD-NA"
+                audit["requestID"] = "MOD-NA"
         return audit
     except Exception as e:
         log.exception("Exception while enriching with entity!", e)
